@@ -1,3 +1,7 @@
+require "active_model"
+require "erb"
+require "yaml"
+
 module AssetSync
   class Config
     include ActiveModel::Validations
@@ -19,11 +23,13 @@ module AssetSync
     attr_accessor :run_on_precompile
     attr_accessor :invalidate
     attr_accessor :cdn_distribution_id
+    attr_accessor :cache_asset_regexps
 
     # FOG configuration
     attr_accessor :fog_provider          # Currently Supported ['AWS', 'Rackspace']
     attr_accessor :fog_directory         # e.g. 'the-bucket-name'
     attr_accessor :fog_region            # e.g. 'eu-west-1'
+    attr_accessor :fog_path_style        # e.g true
 
     # Amazon AWS
     attr_accessor :aws_access_key_id, :aws_secret_access_key, :aws_reduced_redundancy, :aws_iam_roles
@@ -60,12 +66,15 @@ module AssetSync
       self.run_on_precompile = true
       self.cdn_distribution_id = nil
       self.invalidate = []
-      load_yml! if defined?(Rails) && yml_exists?
+      self.cache_asset_regexps = []
+      @additional_local_file_paths_procs = []
+
+      load_yml! if defined?(::Rails) && yml_exists?
     end
 
     def manifest_path
       directory =
-        Rails.application.config.assets.manifest || default_manifest_directory
+        ::Rails.application.config.assets.manifest || default_manifest_directory
       File.join(directory, "manifest.yml")
     end
 
@@ -78,7 +87,7 @@ module AssetSync
     end
 
     def aws?
-      fog_provider == 'AWS'
+      fog_provider =~ /aws/i
     end
 
     def aws_rrs?
@@ -94,7 +103,7 @@ module AssetSync
     end
 
     def log_silently?
-      ENV['RAILS_GROUPS'] == 'assets' || self.log_silently == false
+      !!self.log_silently
     end
 
     def enabled?
@@ -102,36 +111,36 @@ module AssetSync
     end
 
     def rackspace?
-      fog_provider == 'Rackspace'
+      fog_provider =~ /rackspace/i
     end
 
     def google?
-      fog_provider == 'Google'
+      fog_provider =~ /google/i
+    end
+
+    def cache_asset_regexp=(cache_asset_regexp)
+      self.cache_asset_regexps = [cache_asset_regexp]
     end
 
     def yml_exists?
-      defined?(Rails.root) ? File.exists?(self.yml_path) : false
+      defined?(::Rails.root) ? File.exist?(self.yml_path) : false
     end
 
     def yml
-      begin
-        @yml ||= YAML.load(ERB.new(IO.read(yml_path)).result)[Rails.env] rescue nil || {}
-      rescue Psych::SyntaxError
-        @yml = {}
-      end
+      @yml ||= ::YAML.load(::ERB.new(IO.read(yml_path)).result)[::Rails.env] || {}
     end
 
     def yml_path
-      Rails.root.join("config", "asset_sync.yml").to_s
+      ::Rails.root.join("config", "asset_sync.yml").to_s
     end
 
     def assets_prefix
       # Fix for Issue #38 when Rails.config.assets.prefix starts with a slash
-      self.prefix || Rails.application.config.assets.prefix.sub(/^\//, '')
+      self.prefix || ::Rails.application.config.assets.prefix.sub(/^\//, '')
     end
 
     def public_path
-      @public_path || Rails.public_path
+      @public_path || ::Rails.public_path
     end
 
     def load_yml!
@@ -139,6 +148,7 @@ module AssetSync
       self.fog_provider           = yml["fog_provider"]
       self.fog_directory          = yml["fog_directory"]
       self.fog_region             = yml["fog_region"]
+      self.fog_path_style         = yml["fog_path_style"]
       self.aws_access_key_id      = yml["aws_access_key_id"]
       self.aws_secret_access_key  = yml["aws_secret_access_key"]
       self.aws_reduced_redundancy = yml["aws_reduced_redundancy"]
@@ -158,6 +168,7 @@ module AssetSync
       self.run_on_precompile      = yml["run_on_precompile"] if yml.has_key?("run_on_precompile")
       self.invalidate             = yml["invalidate"] if yml.has_key?("invalidate")
       self.cdn_distribution_id    = yml['cdn_distribution_id'] if yml.has_key?("cdn_distribution_id")
+      self.cache_asset_regexps    = yml['cache_asset_regexps'] if yml.has_key?("cache_asset_regexps")
 
       # TODO deprecate the other old style config settings. FML.
       self.aws_access_key_id      = yml["aws_access_key"] if yml.has_key?("aws_access_key")
@@ -203,17 +214,40 @@ module AssetSync
           :google_storage_access_key_id => google_storage_access_key_id
         })
       else
-        raise ArgumentError, "AssetSync Unknown provider: #{fog_provider} only AWS and Rackspace are supported currently."
+        raise ArgumentError, "AssetSync Unknown provider: #{fog_provider} only AWS, Rackspace and Google are supported currently."
       end
 
       options.merge!({:region => fog_region}) if fog_region && !rackspace?
+      options.merge!({:path_style => fog_path_style}) if fog_path_style && aws?
       return options
     end
 
+    # @api
+    def add_local_file_paths(&block)
+      @additional_local_file_paths_procs =
+        additional_local_file_paths_procs + [block]
+    end
+
+    # @api private
+    #   This is to be called in Storage
+    #   Not to be called by user
+    def additional_local_file_paths
+      return [] if additional_local_file_paths_procs.empty?
+
+      # Using `Array()` to ensure it works when single value is returned
+      additional_local_file_paths_procs.each_with_object([]) do |proc, paths|
+        paths.concat(Array(proc.call))
+      end
+    end
+
   private
 
+    # This is a proc to get additional local files paths
+    # Since this is a proc it won't be able to be configured by a YAML file
+    attr_reader :additional_local_file_paths_procs
+
     def default_manifest_directory
-      File.join(Rails.public_path, assets_prefix)
+      File.join(::Rails.public_path, assets_prefix)
     end
   end
 end
